import hvac
from secret_lib.secret_interface import Secret
from secret_lib.exceptions import SecretException


class HscVaultSecret(Secret):

    def __init__(
            self,
            client: hvac.Client,
            paths: [str]
    ):
        # populates _secrets with merging all secrets from the vaults paths
        # be careful to use different names even if there's different paths
        self._secrets = dict()
        for secret_path in paths:
            secret = client.read(secret_path)
            if secret and 'data' in secret:
                secret_data = secret['data']['data']
                for key, value in secret_data.items():
                    if key in self._secrets:
                        raise SecretException(f"Key {key} exists in multiple provided paths. Please use different name to differentiate.")
                    self._secrets[key] = value



from abc import ABC, abstractmethod
from secret_lib.exceptions import SecretException


class Secret(ABC):
    _secrets: dict | None = None

    @abstractmethod
    def __init__(self, *args, **kwargs):
        """should populate the _secrets instance attribute"""

    def get(self, key):
        if not self._secrets:
            raise SecretException(f'Must populate _secrets attribute in init function')
        try:
            return self._secrets[key]
        except KeyError:
            raise KeyError(f'Secret {key} is missing')



import os

from secret_lib.secret_interface import Secret


class EnvironSecret(Secret):

    def __init__(self, *args, prefix: str, **kwargs):
        super().__init__(*args, **kwargs)
        prefix_len = len(prefix)
        self._secrets = {key[prefix_len:]: value for key, value in os.environ.items() if key.startswith(prefix)}



from dotenv import dotenv_values
from secret_lib.secret_interface import Secret


class EnvFileSecret(Secret):

    def __init__(self, *args, file_path: str, **kwargs):
        super().__init__(*args, **kwargs)
        self._secrets = dotenv_values(file_path)



from setuptools import setup, find_packages

setup(
    name="secret_lib",
    version="0.1.1",
    author="vladimir gorea",
    author_email="vladimir@smileservices.dev",
    description="A wrapper for different configuration/secret sources.",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url="https://github.com/smileservices/secret_lib",
    packages=find_packages(),
    install_requires=[
        "hvac",
        "python-dotenv"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
